==> haskell-unexceptionalio-0.5.0-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unexceptionalio.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 unexceptionalio
version:              0.5.0
visibility:           public
id:                   unexceptionalio-0.5.0-6XTdOgDlCq2DlLr3j9Gq6m
key:                  unexceptionalio-0.5.0-6XTdOgDlCq2DlLr3j9Gq6m
license:              LicenseRef-OtherLicense
copyright:            © 2013-2018 Stephen Paul Weber
maintainer:           Stephen Paul Weber <singpolyma@singpolyma.net>
author:               Stephen Paul Weber <singpolyma@singpolyma.net>
stability:            experimental
homepage:             https://github.com/singpolyma/unexceptionalio
synopsis:             IO without any non-error, synchronous exceptions
description:
    When you'\''ve caught all the exceptions that can be handled safely,
    this is what you'\''re left with.

    It is intended that you use qualified imports with this library.

    > import UnexceptionalIO (UIO)
    > import qualified UnexceptionalIO as UIO

    You may also wish to investigate unexceptionalio-trans if you like
    monad transformers.

    Blog post: http://sngpl.ma/p4uT0

category:             Control
abi:                  d6b228d388d361279bc58e45b1dbf2b1
exposed:              True
exposed-modules:      UnexceptionalIO
import-dirs:          /usr/lib/ghc-8.10.1/site-local/unexceptionalio-0.5.0
library-dirs:         /usr/lib/ghc-8.10.1/site-local/unexceptionalio-0.5.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/unexceptionalio-0.5.0
hs-libraries:         HSunexceptionalio-0.5.0-6XTdOgDlCq2DlLr3j9Gq6m
depends:              base-4.14.0.0
haddock-interfaces:
    /usr/share/doc/haskell-unexceptionalio/html/unexceptionalio.haddock

haddock-html:         /usr/share/doc/haskell-unexceptionalio/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unexceptionalio-0.5.1-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unexceptionalio.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 unexceptionalio
version:              0.5.1
visibility:           public
id:                   unexceptionalio-0.5.1-EU4jcegLChzKQral2kkpgD
key:                  unexceptionalio-0.5.1-EU4jcegLChzKQral2kkpgD
license:              LicenseRef-OtherLicense
copyright:            © 2013-2018 Stephen Paul Weber
maintainer:           Stephen Paul Weber <singpolyma@singpolyma.net>
author:               Stephen Paul Weber <singpolyma@singpolyma.net>
stability:            experimental
homepage:             https://github.com/singpolyma/unexceptionalio
synopsis:             IO without any non-error, synchronous exceptions
description:
    When you'\''ve caught all the exceptions that can be handled safely,
    this is what you'\''re left with.

    It is intended that you use qualified imports with this library.

    > import UnexceptionalIO (UIO)
    > import qualified UnexceptionalIO as UIO

    You may also wish to investigate unexceptionalio-trans if you like
    monad transformers.

    Blog post: http://sngpl.ma/p4uT0

category:             Control
abi:                  92173b9abfeff9d3e810b91a4504e98c
exposed:              True
exposed-modules:      UnexceptionalIO
import-dirs:          /usr/lib/ghc-8.10.1/site-local/unexceptionalio-0.5.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/unexceptionalio-0.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/unexceptionalio-0.5.1
hs-libraries:         HSunexceptionalio-0.5.1-EU4jcegLChzKQral2kkpgD
depends:              base-4.14.0.0
haddock-interfaces:
    /usr/share/doc/haskell-unexceptionalio/html/unexceptionalio.haddock

haddock-html:         /usr/share/doc/haskell-unexceptionalio/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
